# coding: utf-8

"""
    (v2.0) Dynamics 365 Business Central

    (v2.0) Business Central Standard APIs

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pybusinesscentral.model.general_ledger_entry import GeneralLedgerEntry

class TestGeneralLedgerEntry(unittest.TestCase):
    """GeneralLedgerEntry unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GeneralLedgerEntry:
        """Test GeneralLedgerEntry
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GeneralLedgerEntry`
        """
        model = GeneralLedgerEntry()
        if include_optional:
            return GeneralLedgerEntry(
                id = 56,
                posting_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                document_number = '',
                document_type = '',
                account_id = '',
                account_number = '',
                description = '',
                debit_amount = 1.337,
                credit_amount = 1.337,
                dimensions = [
                    null
                    ],
                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                account = pybusinesscentral.model.account.account(
                    id = '', 
                    number = '', 
                    display_name = '', 
                    category = '', 
                    sub_category = '', 
                    blocked = True, 
                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
            )
        else:
            return GeneralLedgerEntry(
        )
        """

    def testGeneralLedgerEntry(self):
        """Test GeneralLedgerEntry"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    (v2.0) Dynamics 365 Business Central

    (v2.0) Business Central Standard APIs

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pybusinesscentral.model.list_dimensions200_response import ListDimensions200Response

class TestListDimensions200Response(unittest.TestCase):
    """ListDimensions200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ListDimensions200Response:
        """Test ListDimensions200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ListDimensions200Response`
        """
        model = ListDimensions200Response()
        if include_optional:
            return ListDimensions200Response(
                value = [
                    pybusinesscentral.model.dimension.dimension(
                        id = '', 
                        code = '', 
                        display_name = '', 
                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        dimension_values = [
                            pybusinesscentral.model.dimension_value.dimensionValue(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], )
                    ]
            )
        else:
            return ListDimensions200Response(
        )
        """

    def testListDimensions200Response(self):
        """Test ListDimensions200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    (v2.0) Dynamics 365 Business Central

    (v2.0) Business Central Standard APIs

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from pybusinesscentral.model.default_dimensions import DefaultDimensions
from pybusinesscentral.model.item_category import ItemCategory
from pybusinesscentral.model.itemunitofmeasureconversiontype import Itemunitofmeasureconversiontype
from pybusinesscentral.model.picture import Picture
from typing import Optional, Set
from typing_extensions import Self

class Unitofmeasuretype(BaseModel):
    """
    Unitofmeasuretype
    """ # noqa: E501
    code: Optional[Annotated[str, Field(strict=True, max_length=10)]] = Field(default=None, description="(v1.0) The code property for the Dynamics 365 Business Central unitofmeasuretype entity")
    display_name: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="(v1.0) The displayName property for the Dynamics 365 Business Central unitofmeasuretype entity", alias="displayName")
    symbol: Optional[Annotated[str, Field(strict=True, max_length=10)]] = Field(default=None, description="(v1.0) The symbol property for the Dynamics 365 Business Central unitofmeasuretype entity")
    unit_conversion: Optional[Itemunitofmeasureconversiontype] = Field(default=None, alias="unitConversion")
    picture: Optional[List[Picture]] = None
    default_dimensions: Optional[List[DefaultDimensions]] = Field(default=None, alias="defaultDimensions")
    item_category: Optional[ItemCategory] = Field(default=None, alias="itemCategory")
    __properties: ClassVar[List[str]] = ["code", "displayName", "symbol", "unitConversion", "picture", "defaultDimensions", "itemCategory"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Unitofmeasuretype from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of unit_conversion
        if self.unit_conversion:
            _dict['unitConversion'] = self.unit_conversion.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in picture (list)
        _items = []
        if self.picture:
            for _item_picture in self.picture:
                if _item_picture:
                    _items.append(_item_picture.to_dict())
            _dict['picture'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in default_dimensions (list)
        _items = []
        if self.default_dimensions:
            for _item_default_dimensions in self.default_dimensions:
                if _item_default_dimensions:
                    _items.append(_item_default_dimensions.to_dict())
            _dict['defaultDimensions'] = _items
        # override the default output from pydantic by calling `to_dict()` of item_category
        if self.item_category:
            _dict['itemCategory'] = self.item_category.to_dict()
        # set to None if code (nullable) is None
        # and model_fields_set contains the field
        if self.code is None and "code" in self.model_fields_set:
            _dict['code'] = None

        # set to None if display_name (nullable) is None
        # and model_fields_set contains the field
        if self.display_name is None and "display_name" in self.model_fields_set:
            _dict['displayName'] = None

        # set to None if symbol (nullable) is None
        # and model_fields_set contains the field
        if self.symbol is None and "symbol" in self.model_fields_set:
            _dict['symbol'] = None

        # set to None if unit_conversion (nullable) is None
        # and model_fields_set contains the field
        if self.unit_conversion is None and "unit_conversion" in self.model_fields_set:
            _dict['unitConversion'] = None

        # set to None if picture (nullable) is None
        # and model_fields_set contains the field
        if self.picture is None and "picture" in self.model_fields_set:
            _dict['picture'] = None

        # set to None if default_dimensions (nullable) is None
        # and model_fields_set contains the field
        if self.default_dimensions is None and "default_dimensions" in self.model_fields_set:
            _dict['defaultDimensions'] = None

        # set to None if item_category (nullable) is None
        # and model_fields_set contains the field
        if self.item_category is None and "item_category" in self.model_fields_set:
            _dict['itemCategory'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Unitofmeasuretype from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "code": obj.get("code"),
            "displayName": obj.get("displayName"),
            "symbol": obj.get("symbol"),
            "unitConversion": Itemunitofmeasureconversiontype.from_dict(obj["unitConversion"]) if obj.get("unitConversion") is not None else None,
            "picture": [Picture.from_dict(_item) for _item in obj["picture"]] if obj.get("picture") is not None else None,
            "defaultDimensions": [DefaultDimensions.from_dict(_item) for _item in obj["defaultDimensions"]] if obj.get("defaultDimensions") is not None else None,
            "itemCategory": ItemCategory.from_dict(obj["itemCategory"]) if obj.get("itemCategory") is not None else None
        })
        return _obj





# coding: utf-8

"""
    (v2.0) Dynamics 365 Business Central

    (v2.0) Business Central Standard APIs

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from pybusinesscentral.model.general_ledger_entry_dimensions_inner import GeneralLedgerEntryDimensionsInner
from pybusinesscentral.model.project import Project
from pybusinesscentral.model.unitofmeasuretype import Unitofmeasuretype
from typing import Optional, Set
from typing_extensions import Self

class TimeRegistrationEntry(BaseModel):
    """
    TimeRegistrationEntry
    """ # noqa: E501
    id: Optional[StrictStr] = Field(default=None, description="(v1.0) The id property for the Dynamics 365 Business Central timeRegistrationEntry entity")
    employee_id: Optional[StrictStr] = Field(default=None, description="(v1.0) The employeeId property for the Dynamics 365 Business Central timeRegistrationEntry entity", alias="employeeId")
    employee_number: Optional[Annotated[str, Field(strict=True, max_length=20)]] = Field(default=None, description="(v1.0) The employeeNumber property for the Dynamics 365 Business Central timeRegistrationEntry entity", alias="employeeNumber")
    job_id: Optional[StrictStr] = Field(default=None, description="(v1.0) The jobId property for the Dynamics 365 Business Central timeRegistrationEntry entity", alias="jobId")
    job_number: Optional[Annotated[str, Field(strict=True, max_length=20)]] = Field(default=None, description="(v1.0) The jobNumber property for the Dynamics 365 Business Central timeRegistrationEntry entity", alias="jobNumber")
    absence: Optional[Annotated[str, Field(strict=True, max_length=10)]] = Field(default=None, description="(v1.0) The absence property for the Dynamics 365 Business Central timeRegistrationEntry entity")
    line_number: Optional[StrictInt] = Field(default=None, description="(v1.0) The lineNumber property for the Dynamics 365 Business Central timeRegistrationEntry entity", alias="lineNumber")
    var_date: Optional[datetime] = Field(default=None, description="(v1.0) The date property for the Dynamics 365 Business Central timeRegistrationEntry entity", alias="date")
    quantity: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="(v1.0) The quantity property for the Dynamics 365 Business Central timeRegistrationEntry entity")
    status: Optional[StrictStr] = Field(default=None, description="(v1.0) The status property for the Dynamics 365 Business Central timeRegistrationEntry entity")
    unit_of_measure_id: Optional[StrictStr] = Field(default=None, description="(v1.0) The unitOfMeasureId property for the Dynamics 365 Business Central timeRegistrationEntry entity", alias="unitOfMeasureId")
    unit_of_measure: Optional[Unitofmeasuretype] = Field(default=None, alias="unitOfMeasure")
    dimensions: Optional[List[Optional[GeneralLedgerEntryDimensionsInner]]] = None
    last_modfied_date_time: Optional[datetime] = Field(default=None, description="(v1.0) The lastModfiedDateTime property for the Dynamics 365 Business Central timeRegistrationEntry entity", alias="lastModfiedDateTime")
    project: Optional[Project] = None
    __properties: ClassVar[List[str]] = ["id", "employeeId", "employeeNumber", "jobId", "jobNumber", "absence", "lineNumber", "date", "quantity", "status", "unitOfMeasureId", "unitOfMeasure", "dimensions", "lastModfiedDateTime", "project"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TimeRegistrationEntry from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of unit_of_measure
        if self.unit_of_measure:
            _dict['unitOfMeasure'] = self.unit_of_measure.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in dimensions (list)
        _items = []
        if self.dimensions:
            for _item_dimensions in self.dimensions:
                if _item_dimensions:
                    _items.append(_item_dimensions.to_dict())
            _dict['dimensions'] = _items
        # override the default output from pydantic by calling `to_dict()` of project
        if self.project:
            _dict['project'] = self.project.to_dict()
        # set to None if employee_id (nullable) is None
        # and model_fields_set contains the field
        if self.employee_id is None and "employee_id" in self.model_fields_set:
            _dict['employeeId'] = None

        # set to None if employee_number (nullable) is None
        # and model_fields_set contains the field
        if self.employee_number is None and "employee_number" in self.model_fields_set:
            _dict['employeeNumber'] = None

        # set to None if job_id (nullable) is None
        # and model_fields_set contains the field
        if self.job_id is None and "job_id" in self.model_fields_set:
            _dict['jobId'] = None

        # set to None if job_number (nullable) is None
        # and model_fields_set contains the field
        if self.job_number is None and "job_number" in self.model_fields_set:
            _dict['jobNumber'] = None

        # set to None if absence (nullable) is None
        # and model_fields_set contains the field
        if self.absence is None and "absence" in self.model_fields_set:
            _dict['absence'] = None

        # set to None if line_number (nullable) is None
        # and model_fields_set contains the field
        if self.line_number is None and "line_number" in self.model_fields_set:
            _dict['lineNumber'] = None

        # set to None if var_date (nullable) is None
        # and model_fields_set contains the field
        if self.var_date is None and "var_date" in self.model_fields_set:
            _dict['date'] = None

        # set to None if quantity (nullable) is None
        # and model_fields_set contains the field
        if self.quantity is None and "quantity" in self.model_fields_set:
            _dict['quantity'] = None

        # set to None if status (nullable) is None
        # and model_fields_set contains the field
        if self.status is None and "status" in self.model_fields_set:
            _dict['status'] = None

        # set to None if unit_of_measure_id (nullable) is None
        # and model_fields_set contains the field
        if self.unit_of_measure_id is None and "unit_of_measure_id" in self.model_fields_set:
            _dict['unitOfMeasureId'] = None

        # set to None if unit_of_measure (nullable) is None
        # and model_fields_set contains the field
        if self.unit_of_measure is None and "unit_of_measure" in self.model_fields_set:
            _dict['unitOfMeasure'] = None

        # set to None if last_modfied_date_time (nullable) is None
        # and model_fields_set contains the field
        if self.last_modfied_date_time is None and "last_modfied_date_time" in self.model_fields_set:
            _dict['lastModfiedDateTime'] = None

        # set to None if project (nullable) is None
        # and model_fields_set contains the field
        if self.project is None and "project" in self.model_fields_set:
            _dict['project'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TimeRegistrationEntry from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "employeeId": obj.get("employeeId"),
            "employeeNumber": obj.get("employeeNumber"),
            "jobId": obj.get("jobId"),
            "jobNumber": obj.get("jobNumber"),
            "absence": obj.get("absence"),
            "lineNumber": obj.get("lineNumber"),
            "date": obj.get("date"),
            "quantity": obj.get("quantity"),
            "status": obj.get("status"),
            "unitOfMeasureId": obj.get("unitOfMeasureId"),
            "unitOfMeasure": Unitofmeasuretype.from_dict(obj["unitOfMeasure"]) if obj.get("unitOfMeasure") is not None else None,
            "dimensions": [GeneralLedgerEntryDimensionsInner.from_dict(_item) for _item in obj["dimensions"]] if obj.get("dimensions") is not None else None,
            "lastModfiedDateTime": obj.get("lastModfiedDateTime"),
            "project": Project.from_dict(obj["project"]) if obj.get("project") is not None else None
        })
        return _obj





# coding: utf-8

"""
    (v2.0) Dynamics 365 Business Central

    (v2.0) Business Central Standard APIs

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class TaxGroup(BaseModel):
    """
    TaxGroup
    """ # noqa: E501
    id: Optional[StrictStr] = Field(default=None, description="(v1.0) The id property for the Dynamics 365 Business Central taxGroup entity")
    code: Optional[Annotated[str, Field(strict=True, max_length=20)]] = Field(default=None, description="(v1.0) The code property for the Dynamics 365 Business Central taxGroup entity")
    display_name: Optional[Annotated[str, Field(strict=True, max_length=100)]] = Field(default=None, description="(v1.0) The displayName property for the Dynamics 365 Business Central taxGroup entity", alias="displayName")
    tax_type: Optional[StrictStr] = Field(default=None, description="(v1.0) The taxType property for the Dynamics 365 Business Central taxGroup entity", alias="taxType")
    last_modified_date_time: Optional[datetime] = Field(default=None, description="(v1.0) The lastModifiedDateTime property for the Dynamics 365 Business Central taxGroup entity", alias="lastModifiedDateTime")
    __properties: ClassVar[List[str]] = ["id", "code", "displayName", "taxType", "lastModifiedDateTime"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TaxGroup from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if code (nullable) is None
        # and model_fields_set contains the field
        if self.code is None and "code" in self.model_fields_set:
            _dict['code'] = None

        # set to None if display_name (nullable) is None
        # and model_fields_set contains the field
        if self.display_name is None and "display_name" in self.model_fields_set:
            _dict['displayName'] = None

        # set to None if tax_type (nullable) is None
        # and model_fields_set contains the field
        if self.tax_type is None and "tax_type" in self.model_fields_set:
            _dict['taxType'] = None

        # set to None if last_modified_date_time (nullable) is None
        # and model_fields_set contains the field
        if self.last_modified_date_time is None and "last_modified_date_time" in self.model_fields_set:
            _dict['lastModifiedDateTime'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TaxGroup from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "code": obj.get("code"),
            "displayName": obj.get("displayName"),
            "taxType": obj.get("taxType"),
            "lastModifiedDateTime": obj.get("lastModifiedDateTime")
        })
        return _obj





# coding: utf-8

"""
    (v2.0) Dynamics 365 Business Central

    (v2.0) Business Central Standard APIs

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pybusinesscentral.model.customer_payment import CustomerPayment

class TestCustomerPayment(unittest.TestCase):
    """CustomerPayment unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CustomerPayment:
        """Test CustomerPayment
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CustomerPayment`
        """
        model = CustomerPayment()
        if include_optional:
            return CustomerPayment(
                id = '',
                journal_display_name = '',
                line_number = 56,
                customer_id = '',
                customer_number = '',
                contact_id = '',
                posting_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                document_number = '',
                external_document_number = '',
                amount = 1.337,
                applies_to_invoice_id = '',
                applies_to_invoice_number = '',
                description = '',
                comment = '',
                dimensions = [
                    null
                    ],
                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                customer = pybusinesscentral.model.customer.customer(
                    id = '', 
                    number = '', 
                    display_name = '', 
                    type = '', 
                    address_line1 = '', 
                    address_line2 = '', 
                    city = '', 
                    state = '', 
                    country = '', 
                    postal_code = '', 
                    phone_number = '', 
                    email = '', 
                    website = '', 
                    tax_liable = True, 
                    tax_area_id = '', 
                    tax_area_display_name = '', 
                    tax_registration_number = '', 
                    currency_id = '', 
                    currency_code = '', 
                    payment_terms_id = '', 
                    shipment_method_id = '', 
                    payment_method_id = '', 
                    blocked = '', 
                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    customer_financial_details = [
                        pybusinesscentral.model.customer_financial_detail.customerFinancialDetail(
                            id = '', 
                            number = '', 
                            balance = 1.337, 
                            total_sales_excluding_tax = 1.337, 
                            overdue_amount = 1.337, )
                        ], 
                    picture = [
                        pybusinesscentral.model.picture.picture(
                            id = '', 
                            width = 56, 
                            height = 56, 
                            content_type = '', 
                            content@odata/media_edit_link = '', 
                            content@odata/media_read_link = '', )
                        ], 
                    default_dimensions = [
                        pybusinesscentral.model.default_dimensions.defaultDimensions(
                            parent_id = '', 
                            dimension_id = '', 
                            dimension_code = '', 
                            dimension_value_id = '', 
                            dimension_value_code = '', 
                            posting_validation = '', 
                            account = pybusinesscentral.model.account.account(
                                id = '', 
                                number = '', 
                                display_name = '', 
                                category = '', 
                                sub_category = '', 
                                blocked = True, 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                            dimension = pybusinesscentral.model.dimension.dimension(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                dimension_values = [
                                    pybusinesscentral.model.dimension_value.dimensionValue(
                                        id = '', 
                                        code = '', 
                                        display_name = '', 
                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                    ], ), 
                            dimension_value = pybusinesscentral.model.dimension_value.dimensionValue(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                        ], 
                    currency = pybusinesscentral.model.currency.currency(
                        id = '', 
                        code = '', 
                        display_name = '', 
                        symbol = '', 
                        amount_decimal_places = '', 
                        amount_rounding_precision = 1.337, 
                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                    payment_term = pybusinesscentral.model.payment_term.paymentTerm(
                        id = '', 
                        code = '', 
                        display_name = '', 
                        due_date_calculation = '', 
                        discount_date_calculation = '', 
                        discount_percent = 1.337, 
                        calculate_discount_on_credit_memos = True, 
                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                    shipment_method = pybusinesscentral.model.shipment_method.shipmentMethod(
                        id = '', 
                        code = '', 
                        display_name = '', 
                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                    payment_method = pybusinesscentral.model.payment_method.paymentMethod(
                        id = '', 
                        code = '', 
                        display_name = '', 
                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
            )
        else:
            return CustomerPayment(
        )
        """

    def testCustomerPayment(self):
        """Test CustomerPayment"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    (v2.0) Dynamics 365 Business Central

    (v2.0) Business Central Standard APIs

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from pybusinesscentral.model.postaladdresstype import Postaladdresstype
from typing import Optional, Set
from typing_extensions import Self

class PostPurchaseInvoiceRequest(BaseModel):
    """
    PostPurchaseInvoiceRequest
    """ # noqa: E501
    id: Optional[StrictStr] = Field(default=None, description="(v1.0) The id property for the Dynamics 365 Business Central purchaseInvoice entity")
    number: Optional[Annotated[str, Field(strict=True, max_length=20)]] = Field(default=None, description="(v1.0) The number property for the Dynamics 365 Business Central purchaseInvoice entity")
    invoice_date: Optional[datetime] = Field(default=None, description="(v1.0) The invoiceDate property for the Dynamics 365 Business Central purchaseInvoice entity", alias="invoiceDate")
    due_date: Optional[datetime] = Field(default=None, description="(v1.0) The dueDate property for the Dynamics 365 Business Central purchaseInvoice entity", alias="dueDate")
    vendor_invoice_number: Optional[Annotated[str, Field(strict=True, max_length=35)]] = Field(default=None, description="(v1.0) The vendorInvoiceNumber property for the Dynamics 365 Business Central purchaseInvoice entity", alias="vendorInvoiceNumber")
    vendor_id: Optional[StrictStr] = Field(default=None, description="(v1.0) The vendorId property for the Dynamics 365 Business Central purchaseInvoice entity", alias="vendorId")
    vendor_number: Optional[Annotated[str, Field(strict=True, max_length=20)]] = Field(default=None, description="(v1.0) The vendorNumber property for the Dynamics 365 Business Central purchaseInvoice entity", alias="vendorNumber")
    vendor_name: Optional[Annotated[str, Field(strict=True, max_length=100)]] = Field(default=None, description="(v1.0) The vendorName property for the Dynamics 365 Business Central purchaseInvoice entity", alias="vendorName")
    pay_to_name: Optional[Annotated[str, Field(strict=True, max_length=100)]] = Field(default=None, description="(v1.0) The payToName property for the Dynamics 365 Business Central purchaseInvoice entity", alias="payToName")
    pay_to_contact: Optional[Annotated[str, Field(strict=True, max_length=100)]] = Field(default=None, description="(v1.0) The payToContact property for the Dynamics 365 Business Central purchaseInvoice entity", alias="payToContact")
    pay_to_vendor_id: Optional[StrictStr] = Field(default=None, description="(v1.0) The payToVendorId property for the Dynamics 365 Business Central purchaseInvoice entity", alias="payToVendorId")
    pay_to_vendor_number: Optional[Annotated[str, Field(strict=True, max_length=20)]] = Field(default=None, description="(v1.0) The payToVendorNumber property for the Dynamics 365 Business Central purchaseInvoice entity", alias="payToVendorNumber")
    ship_to_name: Optional[Annotated[str, Field(strict=True, max_length=100)]] = Field(default=None, description="(v1.0) The shipToName property for the Dynamics 365 Business Central purchaseInvoice entity", alias="shipToName")
    ship_to_contact: Optional[Annotated[str, Field(strict=True, max_length=100)]] = Field(default=None, description="(v1.0) The shipToContact property for the Dynamics 365 Business Central purchaseInvoice entity", alias="shipToContact")
    buy_from_address: Optional[Postaladdresstype] = Field(default=None, alias="buyFromAddress")
    pay_to_address: Optional[Postaladdresstype] = Field(default=None, alias="payToAddress")
    ship_to_address: Optional[Postaladdresstype] = Field(default=None, alias="shipToAddress")
    currency_id: Optional[StrictStr] = Field(default=None, description="(v1.0) The currencyId property for the Dynamics 365 Business Central purchaseInvoice entity", alias="currencyId")
    currency_code: Optional[StrictStr] = Field(default=None, description="(v1.0) The currencyCode property for the Dynamics 365 Business Central purchaseInvoice entity", alias="currencyCode")
    prices_include_tax: Optional[StrictBool] = Field(default=None, description="(v1.0) The pricesIncludeTax property for the Dynamics 365 Business Central purchaseInvoice entity", alias="pricesIncludeTax")
    discount_amount: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="(v1.0) The discountAmount property for the Dynamics 365 Business Central purchaseInvoice entity", alias="discountAmount")
    discount_applied_before_tax: Optional[StrictBool] = Field(default=None, description="(v1.0) The discountAppliedBeforeTax property for the Dynamics 365 Business Central purchaseInvoice entity", alias="discountAppliedBeforeTax")
    total_amount_excluding_tax: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="(v1.0) The totalAmountExcludingTax property for the Dynamics 365 Business Central purchaseInvoice entity", alias="totalAmountExcludingTax")
    total_tax_amount: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="(v1.0) The totalTaxAmount property for the Dynamics 365 Business Central purchaseInvoice entity", alias="totalTaxAmount")
    total_amount_including_tax: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="(v1.0) The totalAmountIncludingTax property for the Dynamics 365 Business Central purchaseInvoice entity", alias="totalAmountIncludingTax")
    status: Optional[StrictStr] = Field(default=None, description="(v1.0) The status property for the Dynamics 365 Business Central purchaseInvoice entity")
    last_modified_date_time: Optional[datetime] = Field(default=None, description="(v1.0) The lastModifiedDateTime property for the Dynamics 365 Business Central purchaseInvoice entity", alias="lastModifiedDateTime")
    __properties: ClassVar[List[str]] = ["id", "number", "invoiceDate", "dueDate", "vendorInvoiceNumber", "vendorId", "vendorNumber", "vendorName", "payToName", "payToContact", "payToVendorId", "payToVendorNumber", "shipToName", "shipToContact", "buyFromAddress", "payToAddress", "shipToAddress", "currencyId", "currencyCode", "pricesIncludeTax", "discountAmount", "discountAppliedBeforeTax", "totalAmountExcludingTax", "totalTaxAmount", "totalAmountIncludingTax", "status", "lastModifiedDateTime"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PostPurchaseInvoiceRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of buy_from_address
        if self.buy_from_address:
            _dict['buyFromAddress'] = self.buy_from_address.to_dict()
        # override the default output from pydantic by calling `to_dict()` of pay_to_address
        if self.pay_to_address:
            _dict['payToAddress'] = self.pay_to_address.to_dict()
        # override the default output from pydantic by calling `to_dict()` of ship_to_address
        if self.ship_to_address:
            _dict['shipToAddress'] = self.ship_to_address.to_dict()
        # set to None if number (nullable) is None
        # and model_fields_set contains the field
        if self.number is None and "number" in self.model_fields_set:
            _dict['number'] = None

        # set to None if invoice_date (nullable) is None
        # and model_fields_set contains the field
        if self.invoice_date is None and "invoice_date" in self.model_fields_set:
            _dict['invoiceDate'] = None

        # set to None if due_date (nullable) is None
        # and model_fields_set contains the field
        if self.due_date is None and "due_date" in self.model_fields_set:
            _dict['dueDate'] = None

        # set to None if vendor_invoice_number (nullable) is None
        # and model_fields_set contains the field
        if self.vendor_invoice_number is None and "vendor_invoice_number" in self.model_fields_set:
            _dict['vendorInvoiceNumber'] = None

        # set to None if vendor_id (nullable) is None
        # and model_fields_set contains the field
        if self.vendor_id is None and "vendor_id" in self.model_fields_set:
            _dict['vendorId'] = None

        # set to None if vendor_number (nullable) is None
        # and model_fields_set contains the field
        if self.vendor_number is None and "vendor_number" in self.model_fields_set:
            _dict['vendorNumber'] = None

        # set to None if vendor_name (nullable) is None
        # and model_fields_set contains the field
        if self.vendor_name is None and "vendor_name" in self.model_fields_set:
            _dict['vendorName'] = None

        # set to None if pay_to_name (nullable) is None
        # and model_fields_set contains the field
        if self.pay_to_name is None and "pay_to_name" in self.model_fields_set:
            _dict['payToName'] = None

        # set to None if pay_to_contact (nullable) is None
        # and model_fields_set contains the field
        if self.pay_to_contact is None and "pay_to_contact" in self.model_fields_set:
            _dict['payToContact'] = None

        # set to None if pay_to_vendor_id (nullable) is None
        # and model_fields_set contains the field
        if self.pay_to_vendor_id is None and "pay_to_vendor_id" in self.model_fields_set:
            _dict['payToVendorId'] = None

        # set to None if pay_to_vendor_number (nullable) is None
        # and model_fields_set contains the field
        if self.pay_to_vendor_number is None and "pay_to_vendor_number" in self.model_fields_set:
            _dict['payToVendorNumber'] = None

        # set to None if ship_to_name (nullable) is None
        # and model_fields_set contains the field
        if self.ship_to_name is None and "ship_to_name" in self.model_fields_set:
            _dict['shipToName'] = None

        # set to None if ship_to_contact (nullable) is None
        # and model_fields_set contains the field
        if self.ship_to_contact is None and "ship_to_contact" in self.model_fields_set:
            _dict['shipToContact'] = None

        # set to None if buy_from_address (nullable) is None
        # and model_fields_set contains the field
        if self.buy_from_address is None and "buy_from_address" in self.model_fields_set:
            _dict['buyFromAddress'] = None

        # set to None if pay_to_address (nullable) is None
        # and model_fields_set contains the field
        if self.pay_to_address is None and "pay_to_address" in self.model_fields_set:
            _dict['payToAddress'] = None

        # set to None if ship_to_address (nullable) is None
        # and model_fields_set contains the field
        if self.ship_to_address is None and "ship_to_address" in self.model_fields_set:
            _dict['shipToAddress'] = None

        # set to None if currency_id (nullable) is None
        # and model_fields_set contains the field
        if self.currency_id is None and "currency_id" in self.model_fields_set:
            _dict['currencyId'] = None

        # set to None if currency_code (nullable) is None
        # and model_fields_set contains the field
        if self.currency_code is None and "currency_code" in self.model_fields_set:
            _dict['currencyCode'] = None

        # set to None if prices_include_tax (nullable) is None
        # and model_fields_set contains the field
        if self.prices_include_tax is None and "prices_include_tax" in self.model_fields_set:
            _dict['pricesIncludeTax'] = None

        # set to None if discount_amount (nullable) is None
        # and model_fields_set contains the field
        if self.discount_amount is None and "discount_amount" in self.model_fields_set:
            _dict['discountAmount'] = None

        # set to None if discount_applied_before_tax (nullable) is None
        # and model_fields_set contains the field
        if self.discount_applied_before_tax is None and "discount_applied_before_tax" in self.model_fields_set:
            _dict['discountAppliedBeforeTax'] = None

        # set to None if total_amount_excluding_tax (nullable) is None
        # and model_fields_set contains the field
        if self.total_amount_excluding_tax is None and "total_amount_excluding_tax" in self.model_fields_set:
            _dict['totalAmountExcludingTax'] = None

        # set to None if total_tax_amount (nullable) is None
        # and model_fields_set contains the field
        if self.total_tax_amount is None and "total_tax_amount" in self.model_fields_set:
            _dict['totalTaxAmount'] = None

        # set to None if total_amount_including_tax (nullable) is None
        # and model_fields_set contains the field
        if self.total_amount_including_tax is None and "total_amount_including_tax" in self.model_fields_set:
            _dict['totalAmountIncludingTax'] = None

        # set to None if status (nullable) is None
        # and model_fields_set contains the field
        if self.status is None and "status" in self.model_fields_set:
            _dict['status'] = None

        # set to None if last_modified_date_time (nullable) is None
        # and model_fields_set contains the field
        if self.last_modified_date_time is None and "last_modified_date_time" in self.model_fields_set:
            _dict['lastModifiedDateTime'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PostPurchaseInvoiceRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "number": obj.get("number"),
            "invoiceDate": obj.get("invoiceDate"),
            "dueDate": obj.get("dueDate"),
            "vendorInvoiceNumber": obj.get("vendorInvoiceNumber"),
            "vendorId": obj.get("vendorId"),
            "vendorNumber": obj.get("vendorNumber"),
            "vendorName": obj.get("vendorName"),
            "payToName": obj.get("payToName"),
            "payToContact": obj.get("payToContact"),
            "payToVendorId": obj.get("payToVendorId"),
            "payToVendorNumber": obj.get("payToVendorNumber"),
            "shipToName": obj.get("shipToName"),
            "shipToContact": obj.get("shipToContact"),
            "buyFromAddress": Postaladdresstype.from_dict(obj["buyFromAddress"]) if obj.get("buyFromAddress") is not None else None,
            "payToAddress": Postaladdresstype.from_dict(obj["payToAddress"]) if obj.get("payToAddress") is not None else None,
            "shipToAddress": Postaladdresstype.from_dict(obj["shipToAddress"]) if obj.get("shipToAddress") is not None else None,
            "currencyId": obj.get("currencyId"),
            "currencyCode": obj.get("currencyCode"),
            "pricesIncludeTax": obj.get("pricesIncludeTax"),
            "discountAmount": obj.get("discountAmount"),
            "discountAppliedBeforeTax": obj.get("discountAppliedBeforeTax"),
            "totalAmountExcludingTax": obj.get("totalAmountExcludingTax"),
            "totalTaxAmount": obj.get("totalTaxAmount"),
            "totalAmountIncludingTax": obj.get("totalAmountIncludingTax"),
            "status": obj.get("status"),
            "lastModifiedDateTime": obj.get("lastModifiedDateTime")
        })
        return _obj





# coding: utf-8

"""
    (v2.0) Dynamics 365 Business Central

    (v2.0) Business Central Standard APIs

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class Picture(BaseModel):
    """
    Picture
    """ # noqa: E501
    id: Optional[StrictStr] = Field(default=None, description="(v1.0) The id property for the Dynamics 365 Business Central picture entity")
    width: Optional[StrictInt] = Field(default=None, description="(v1.0) The width property for the Dynamics 365 Business Central picture entity")
    height: Optional[StrictInt] = Field(default=None, description="(v1.0) The height property for the Dynamics 365 Business Central picture entity")
    content_type: Optional[Annotated[str, Field(strict=True, max_length=100)]] = Field(default=None, description="(v1.0) The contentType property for the Dynamics 365 Business Central picture entity", alias="contentType")
    contentodata_media_edit_link: Optional[StrictStr] = Field(default=None, description="(v1.0) The content@odata.mediaEditLink property for the Dynamics 365 Business Central picture entity", alias="content@odata.mediaEditLink")
    contentodata_media_read_link: Optional[StrictStr] = Field(default=None, description="(v1.0) The content@odata.mediaReadLink property for the Dynamics 365 Business Central picture entity", alias="content@odata.mediaReadLink")
    __properties: ClassVar[List[str]] = ["id", "width", "height", "contentType", "content@odata.mediaEditLink", "content@odata.mediaReadLink"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Picture from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if width (nullable) is None
        # and model_fields_set contains the field
        if self.width is None and "width" in self.model_fields_set:
            _dict['width'] = None

        # set to None if height (nullable) is None
        # and model_fields_set contains the field
        if self.height is None and "height" in self.model_fields_set:
            _dict['height'] = None

        # set to None if content_type (nullable) is None
        # and model_fields_set contains the field
        if self.content_type is None and "content_type" in self.model_fields_set:
            _dict['contentType'] = None

        # set to None if contentodata_media_edit_link (nullable) is None
        # and model_fields_set contains the field
        if self.contentodata_media_edit_link is None and "contentodata_media_edit_link" in self.model_fields_set:
            _dict['content@odata.mediaEditLink'] = None

        # set to None if contentodata_media_read_link (nullable) is None
        # and model_fields_set contains the field
        if self.contentodata_media_read_link is None and "contentodata_media_read_link" in self.model_fields_set:
            _dict['content@odata.mediaReadLink'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Picture from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "width": obj.get("width"),
            "height": obj.get("height"),
            "contentType": obj.get("contentType"),
            "content@odata.mediaEditLink": obj.get("content@odata.mediaEditLink"),
            "content@odata.mediaReadLink": obj.get("content@odata.mediaReadLink")
        })
        return _obj





# coding: utf-8

"""
    (v2.0) Dynamics 365 Business Central

    (v2.0) Business Central Standard APIs

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class AgedAccountsReceivable(BaseModel):
    """
    AgedAccountsReceivable
    """ # noqa: E501
    customer_id: Optional[StrictStr] = Field(default=None, description="(v1.0) The customerId property for the Dynamics 365 Business Central agedAccountsReceivable entity", alias="customerId")
    customer_number: Optional[Annotated[str, Field(strict=True, max_length=20)]] = Field(default=None, description="(v1.0) The customerNumber property for the Dynamics 365 Business Central agedAccountsReceivable entity", alias="customerNumber")
    name: Optional[Annotated[str, Field(strict=True, max_length=100)]] = Field(default=None, description="(v1.0) The name property for the Dynamics 365 Business Central agedAccountsReceivable entity")
    currency_code: Optional[Annotated[str, Field(strict=True, max_length=10)]] = Field(default=None, description="(v1.0) The currencyCode property for the Dynamics 365 Business Central agedAccountsReceivable entity", alias="currencyCode")
    balance_due: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="(v1.0) The balanceDue property for the Dynamics 365 Business Central agedAccountsReceivable entity", alias="balanceDue")
    current_amount: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="(v1.0) The currentAmount property for the Dynamics 365 Business Central agedAccountsReceivable entity", alias="currentAmount")
    period1_amount: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="(v1.0) The period1Amount property for the Dynamics 365 Business Central agedAccountsReceivable entity", alias="period1Amount")
    period2_amount: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="(v1.0) The period2Amount property for the Dynamics 365 Business Central agedAccountsReceivable entity", alias="period2Amount")
    period3_amount: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="(v1.0) The period3Amount property for the Dynamics 365 Business Central agedAccountsReceivable entity", alias="period3Amount")
    aged_as_of_date: Optional[datetime] = Field(default=None, description="(v1.0) The agedAsOfDate property for the Dynamics 365 Business Central agedAccountsReceivable entity", alias="agedAsOfDate")
    period_length_filter: Optional[Annotated[str, Field(strict=True, max_length=10)]] = Field(default=None, description="(v1.0) The periodLengthFilter property for the Dynamics 365 Business Central agedAccountsReceivable entity", alias="periodLengthFilter")
    __properties: ClassVar[List[str]] = ["customerId", "customerNumber", "name", "currencyCode", "balanceDue", "currentAmount", "period1Amount", "period2Amount", "period3Amount", "agedAsOfDate", "periodLengthFilter"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AgedAccountsReceivable from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if customer_number (nullable) is None
        # and model_fields_set contains the field
        if self.customer_number is None and "customer_number" in self.model_fields_set:
            _dict['customerNumber'] = None

        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if currency_code (nullable) is None
        # and model_fields_set contains the field
        if self.currency_code is None and "currency_code" in self.model_fields_set:
            _dict['currencyCode'] = None

        # set to None if balance_due (nullable) is None
        # and model_fields_set contains the field
        if self.balance_due is None and "balance_due" in self.model_fields_set:
            _dict['balanceDue'] = None

        # set to None if current_amount (nullable) is None
        # and model_fields_set contains the field
        if self.current_amount is None and "current_amount" in self.model_fields_set:
            _dict['currentAmount'] = None

        # set to None if period1_amount (nullable) is None
        # and model_fields_set contains the field
        if self.period1_amount is None and "period1_amount" in self.model_fields_set:
            _dict['period1Amount'] = None

        # set to None if period2_amount (nullable) is None
        # and model_fields_set contains the field
        if self.period2_amount is None and "period2_amount" in self.model_fields_set:
            _dict['period2Amount'] = None

        # set to None if period3_amount (nullable) is None
        # and model_fields_set contains the field
        if self.period3_amount is None and "period3_amount" in self.model_fields_set:
            _dict['period3Amount'] = None

        # set to None if aged_as_of_date (nullable) is None
        # and model_fields_set contains the field
        if self.aged_as_of_date is None and "aged_as_of_date" in self.model_fields_set:
            _dict['agedAsOfDate'] = None

        # set to None if period_length_filter (nullable) is None
        # and model_fields_set contains the field
        if self.period_length_filter is None and "period_length_filter" in self.model_fields_set:
            _dict['periodLengthFilter'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AgedAccountsReceivable from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "customerId": obj.get("customerId"),
            "customerNumber": obj.get("customerNumber"),
            "name": obj.get("name"),
            "currencyCode": obj.get("currencyCode"),
            "balanceDue": obj.get("balanceDue"),
            "currentAmount": obj.get("currentAmount"),
            "period1Amount": obj.get("period1Amount"),
            "period2Amount": obj.get("period2Amount"),
            "period3Amount": obj.get("period3Amount"),
            "agedAsOfDate": obj.get("agedAsOfDate"),
            "periodLengthFilter": obj.get("periodLengthFilter")
        })
        return _obj





# coding: utf-8

"""
    (v2.0) Dynamics 365 Business Central

    (v2.0) Business Central Standard APIs

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pybusinesscentral.api.payment_term_api import PaymentTermApi


class TestPaymentTermApi(unittest.TestCase):
    """PaymentTermApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PaymentTermApi()

    def tearDown(self) -> None:
        pass

    def test_delete_payment_term(self) -> None:
        """Test case for delete_payment_term

        Deletes an object of type paymentTerm in Dynamics 365 Business Central
        """
        pass

    def test_get_payment_term(self) -> None:
        """Test case for get_payment_term

        Retrieve the properties and relationships of an object of type paymentTerm for Dynamics 365 Business Central.
        """
        pass

    def test_list_payment_terms(self) -> None:
        """Test case for list_payment_terms

        Returns a list of paymentTerms
        """
        pass

    def test_patch_payment_term(self) -> None:
        """Test case for patch_payment_term

        Updates an object of type paymentTerm in Dynamics 365 Business Central
        """
        pass

    def test_post_payment_term(self) -> None:
        """Test case for post_payment_term

        Creates an object of type paymentTerm in Dynamics 365 Business Central
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    (v2.0) Dynamics 365 Business Central

    (v2.0) Business Central Standard APIs

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pybusinesscentral.model.list_companies200_response import ListCompanies200Response

class TestListCompanies200Response(unittest.TestCase):
    """ListCompanies200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ListCompanies200Response:
        """Test ListCompanies200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ListCompanies200Response`
        """
        model = ListCompanies200Response()
        if include_optional:
            return ListCompanies200Response(
                value = [
                    pybusinesscentral.model.company.company(
                        id = '', 
                        system_version = '', 
                        name = '', 
                        display_name = '', 
                        business_profile_id = '', 
                        items = [
                            pybusinesscentral.model.item.item(
                                id = '', 
                                number = '', 
                                display_name = '', 
                                type = '', 
                                item_category_id = '', 
                                item_category_code = '', 
                                blocked = True, 
                                base_unit_of_measure_id = '', 
                                base_unit_of_measure = pybusinesscentral.model.unitofmeasuretype.unitofmeasuretype(
                                    code = '', 
                                    display_name = '', 
                                    symbol = '', 
                                    unit_conversion = pybusinesscentral.model.itemunitofmeasureconversiontype.itemunitofmeasureconversiontype(
                                        to_unit_of_measure = '', 
                                        from_to_conversion_rate = 1.337, 
                                        picture = [
                                            pybusinesscentral.model.picture.picture(
                                                id = '', 
                                                width = 56, 
                                                height = 56, 
                                                content_type = '', 
                                                content@odata/media_edit_link = '', 
                                                content@odata/media_read_link = '', )
                                            ], 
                                        default_dimensions = [
                                            pybusinesscentral.model.default_dimensions.defaultDimensions(
                                                parent_id = '', 
                                                dimension_id = '', 
                                                dimension_code = '', 
                                                dimension_value_id = '', 
                                                dimension_value_code = '', 
                                                posting_validation = '', 
                                                account = pybusinesscentral.model.account.account(
                                                    id = '', 
                                                    number = '', 
                                                    display_name = '', 
                                                    category = '', 
                                                    sub_category = '', 
                                                    blocked = True, 
                                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                                                dimension = pybusinesscentral.model.dimension.dimension(
                                                    id = '', 
                                                    code = '', 
                                                    display_name = '', 
                                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    dimension_values = [
                                                        pybusinesscentral.model.dimension_value.dimensionValue(
                                                            id = '', 
                                                            code = '', 
                                                            display_name = '', 
                                                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                        ], ), 
                                                dimension_value = pybusinesscentral.model.dimension_value.dimensionValue(
                                                    id = '', 
                                                    code = '', 
                                                    display_name = '', 
                                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                                            ], 
                                        item_category = pybusinesscentral.model.item_category.itemCategory(
                                            id = '', 
                                            code = '', 
                                            display_name = '', 
                                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                                    picture = [
                                        pybusinesscentral.model.picture.picture(
                                            id = '', 
                                            width = 56, 
                                            height = 56, 
                                            content_type = '', 
                                            content@odata/media_edit_link = '', 
                                            content@odata/media_read_link = '', )
                                        ], 
                                    default_dimensions = [
                                        pybusinesscentral.model.default_dimensions.defaultDimensions(
                                            parent_id = '', 
                                            dimension_id = '', 
                                            dimension_code = '', 
                                            dimension_value_id = '', 
                                            dimension_value_code = '', 
                                            posting_validation = '', )
                                        ], 
                                    item_category = pybusinesscentral.model.item_category.itemCategory(
                                        id = '', 
                                        code = '', 
                                        display_name = '', 
                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                                gtin = '', 
                                inventory = 1.337, 
                                unit_price = 1.337, 
                                price_includes_tax = True, 
                                unit_cost = 1.337, 
                                tax_group_id = '', 
                                tax_group_code = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                picture = , 
                                default_dimensions = , 
                                item_category = , )
                            ], 
                        picture = , 
                        default_dimensions = , 
                        customers = [
                            pybusinesscentral.model.customer.customer(
                                id = '', 
                                number = '', 
                                display_name = '', 
                                type = '', 
                                address_line1 = '', 
                                address_line2 = '', 
                                city = '', 
                                state = '', 
                                country = '', 
                                postal_code = '', 
                                phone_number = '', 
                                email = '', 
                                website = '', 
                                tax_liable = True, 
                                tax_area_id = '', 
                                tax_area_display_name = '', 
                                tax_registration_number = '', 
                                currency_id = '', 
                                currency_code = '', 
                                payment_terms_id = '', 
                                shipment_method_id = '', 
                                payment_method_id = '', 
                                blocked = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                customer_financial_details = [
                                    pybusinesscentral.model.customer_financial_detail.customerFinancialDetail(
                                        id = '', 
                                        number = '', 
                                        balance = 1.337, 
                                        total_sales_excluding_tax = 1.337, 
                                        overdue_amount = 1.337, )
                                    ], 
                                currency = pybusinesscentral.model.currency.currency(
                                    id = '', 
                                    code = '', 
                                    display_name = '', 
                                    symbol = '', 
                                    amount_decimal_places = '', 
                                    amount_rounding_precision = 1.337, 
                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                                payment_term = pybusinesscentral.model.payment_term.paymentTerm(
                                    id = '', 
                                    code = '', 
                                    display_name = '', 
                                    due_date_calculation = '', 
                                    discount_date_calculation = '', 
                                    discount_percent = 1.337, 
                                    calculate_discount_on_credit_memos = True, 
                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                                shipment_method = pybusinesscentral.model.shipment_method.shipmentMethod(
                                    id = '', 
                                    code = '', 
                                    display_name = '', 
                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                                payment_method = pybusinesscentral.model.payment_method.paymentMethod(
                                    id = '', 
                                    code = '', 
                                    display_name = '', 
                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                            ], 
                        customer_financial_details = [
                            pybusinesscentral.model.customer_financial_detail.customerFinancialDetail(
                                id = '', 
                                number = '', 
                                balance = 1.337, 
                                total_sales_excluding_tax = 1.337, 
                                overdue_amount = 1.337, )
                            ], 
                        vendors = [
                            pybusinesscentral.model.vendor.vendor(
                                id = '', 
                                number = '', 
                                display_name = '', 
                                address_line1 = '', 
                                address_line2 = '', 
                                city = '', 
                                state = '', 
                                country = '', 
                                postal_code = '', 
                                phone_number = '', 
                                email = '', 
                                website = '', 
                                tax_registration_number = '', 
                                currency_id = '', 
                                currency_code = '', 
                                irs1099_code = '', 
                                payment_terms_id = '', 
                                payment_method_id = '', 
                                tax_liable = True, 
                                blocked = '', 
                                balance = 1.337, 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], 
                        company_information = [
                            pybusinesscentral.model.company_information.companyInformation(
                                id = '', 
                                display_name = '', 
                                address = pybusinesscentral.model.postaladdresstype.postaladdresstype(
                                    street = '', 
                                    city = '', 
                                    state = '', 
                                    country_letter_code = '', 
                                    postal_code = '', ), 
                                phone_number = '', 
                                fax_number = '', 
                                email = '', 
                                website = '', 
                                tax_registration_number = '', 
                                currency_code = '', 
                                current_fiscal_year_start_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                industry = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], 
                        sales_invoices = [
                            pybusinesscentral.model.sales_invoice.salesInvoice(
                                id = '', 
                                number = '', 
                                external_document_number = '', 
                                invoice_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                                due_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                                customer_purchase_order_reference = '', 
                                customer_id = '', 
                                contact_id = '', 
                                customer_number = '', 
                                customer_name = '', 
                                bill_to_name = '', 
                                bill_to_customer_id = '', 
                                bill_to_customer_number = '', 
                                ship_to_name = '', 
                                ship_to_contact = '', 
                                selling_postal_address = pybusinesscentral.model.postaladdresstype.postaladdresstype(
                                    street = '', 
                                    city = '', 
                                    state = '', 
                                    country_letter_code = '', 
                                    postal_code = '', ), 
                                billing_postal_address = , 
                                shipping_postal_address = , 
                                currency_id = '', 
                                currency_code = '', 
                                order_id = '', 
                                order_number = '', 
                                payment_terms_id = '', 
                                shipment_method_id = '', 
                                salesperson = '', 
                                prices_include_tax = True, 
                                remaining_amount = 1.337, 
                                discount_amount = 1.337, 
                                discount_applied_before_tax = True, 
                                total_amount_excluding_tax = 1.337, 
                                total_tax_amount = 1.337, 
                                total_amount_including_tax = 1.337, 
                                status = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                phone_number = '', 
                                email = '', 
                                sales_invoice_lines = [
                                    pybusinesscentral.model.sales_invoice_line.salesInvoiceLine(
                                        id = '', 
                                        document_id = '', 
                                        sequence = 56, 
                                        item_id = '', 
                                        account_id = '', 
                                        line_type = '', 
                                        line_details = pybusinesscentral.model.documentlineobjectdetailstype.documentlineobjectdetailstype(
                                            number = '', 
                                            display_name = '', ), 
                                        description = '', 
                                        unit_of_measure_id = '', 
                                        unit_of_measure = pybusinesscentral.model.unitofmeasuretype.unitofmeasuretype(
                                            code = '', 
                                            display_name = '', 
                                            symbol = '', ), 
                                        unit_price = 1.337, 
                                        quantity = 1.337, 
                                        discount_amount = 1.337, 
                                        discount_percent = 1.337, 
                                        discount_applied_before_tax = True, 
                                        amount_excluding_tax = 1.337, 
                                        tax_code = '', 
                                        tax_percent = 1.337, 
                                        total_tax_amount = 1.337, 
                                        amount_including_tax = 1.337, 
                                        invoice_discount_allocation = 1.337, 
                                        net_amount = 1.337, 
                                        net_tax_amount = 1.337, 
                                        net_amount_including_tax = 1.337, 
                                        shipment_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), )
                                    ], 
                                pdf_document = [
                                    pybusinesscentral.model.pdf_document.pdfDocument(
                                        id = '', 
                                        content = bytes(b'blah'), )
                                    ], )
                            ], 
                        sales_invoice_lines = [
                            pybusinesscentral.model.sales_invoice_line.salesInvoiceLine(
                                id = '', 
                                document_id = '', 
                                sequence = 56, 
                                item_id = '', 
                                account_id = '', 
                                line_type = '', 
                                description = '', 
                                unit_of_measure_id = '', 
                                unit_price = 1.337, 
                                quantity = 1.337, 
                                discount_amount = 1.337, 
                                discount_percent = 1.337, 
                                discount_applied_before_tax = True, 
                                amount_excluding_tax = 1.337, 
                                tax_code = '', 
                                tax_percent = 1.337, 
                                total_tax_amount = 1.337, 
                                amount_including_tax = 1.337, 
                                invoice_discount_allocation = 1.337, 
                                net_amount = 1.337, 
                                net_tax_amount = 1.337, 
                                net_amount_including_tax = 1.337, 
                                shipment_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), )
                            ], 
                        pdf_document = [
                            pybusinesscentral.model.pdf_document.pdfDocument(
                                id = '', 
                                content = bytes(b'blah'), )
                            ], 
                        customer_payment_journals = [
                            pybusinesscentral.model.customer_payment_journal.customerPaymentJournal(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                balancing_account_id = '', 
                                balancing_account_number = '', 
                                customer_payments = [
                                    pybusinesscentral.model.customer_payment.customerPayment(
                                        id = '', 
                                        journal_display_name = '', 
                                        line_number = 56, 
                                        customer_id = '', 
                                        customer_number = '', 
                                        contact_id = '', 
                                        posting_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        document_number = '', 
                                        external_document_number = '', 
                                        amount = 1.337, 
                                        applies_to_invoice_id = '', 
                                        applies_to_invoice_number = '', 
                                        description = '', 
                                        comment = '', 
                                        dimensions = [
                                            null
                                            ], 
                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                    ], )
                            ], 
                        customer_payments = [
                            pybusinesscentral.model.customer_payment.customerPayment(
                                id = '', 
                                journal_display_name = '', 
                                line_number = 56, 
                                customer_id = '', 
                                customer_number = '', 
                                contact_id = '', 
                                posting_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                document_number = '', 
                                external_document_number = '', 
                                amount = 1.337, 
                                applies_to_invoice_id = '', 
                                applies_to_invoice_number = '', 
                                description = '', 
                                comment = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], 
                        accounts = [
                            pybusinesscentral.model.account.account(
                                id = '', 
                                number = '', 
                                display_name = '', 
                                category = '', 
                                sub_category = '', 
                                blocked = True, 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], 
                        tax_groups = [
                            pybusinesscentral.model.tax_group.taxGroup(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                tax_type = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], 
                        journals = [
                            pybusinesscentral.model.journal.journal(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                balancing_account_id = '', 
                                balancing_account_number = '', 
                                journal_lines = [
                                    pybusinesscentral.model.journal_line.journalLine(
                                        id = '', 
                                        journal_display_name = '', 
                                        line_number = 56, 
                                        account_type = '', 
                                        account_id = '', 
                                        account_number = '', 
                                        posting_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        document_number = '', 
                                        external_document_number = '', 
                                        amount = 1.337, 
                                        description = '', 
                                        comment = '', 
                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        attachments = [
                                            pybusinesscentral.model.attachments.attachments(
                                                parent_id = '', 
                                                id = '', 
                                                file_name = '', 
                                                byte_size = 56, 
                                                content = bytes(b'blah'), 
                                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                            ], )
                                    ], )
                            ], 
                        journal_lines = [
                            pybusinesscentral.model.journal_line.journalLine(
                                id = '', 
                                journal_display_name = '', 
                                line_number = 56, 
                                account_type = '', 
                                account_id = '', 
                                account_number = '', 
                                posting_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                document_number = '', 
                                external_document_number = '', 
                                amount = 1.337, 
                                description = '', 
                                comment = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], 
                        attachments = [
                            pybusinesscentral.model.attachments.attachments(
                                parent_id = '', 
                                id = '', 
                                file_name = '', 
                                byte_size = 56, 
                                content = bytes(b'blah'), 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], 
                        employees = [
                            pybusinesscentral.model.employee.employee(
                                id = '', 
                                number = '', 
                                display_name = '', 
                                given_name = '', 
                                middle_name = '', 
                                surname = '', 
                                job_title = '', 
                                phone_number = '', 
                                mobile_phone = '', 
                                email = '', 
                                personal_email = '', 
                                employment_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                termination_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                status = '', 
                                birth_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                statistics_group_code = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                time_registration_entries = [
                                    pybusinesscentral.model.time_registration_entry.timeRegistrationEntry(
                                        id = '', 
                                        employee_id = '', 
                                        employee_number = '', 
                                        job_id = '', 
                                        job_number = '', 
                                        absence = '', 
                                        line_number = 56, 
                                        date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        quantity = 1.337, 
                                        status = '', 
                                        unit_of_measure_id = '', 
                                        last_modfied_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        project = pybusinesscentral.model.project.project(
                                            id = '', 
                                            number = '', 
                                            display_name = '', ), )
                                    ], )
                            ], 
                        time_registration_entries = [
                            pybusinesscentral.model.time_registration_entry.timeRegistrationEntry(
                                id = '', 
                                employee_id = '', 
                                employee_number = '', 
                                job_id = '', 
                                job_number = '', 
                                absence = '', 
                                line_number = 56, 
                                date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                quantity = 1.337, 
                                status = '', 
                                unit_of_measure_id = '', 
                                last_modfied_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], 
                        general_ledger_entries = [
                            pybusinesscentral.model.general_ledger_entry.generalLedgerEntry(
                                id = 56, 
                                posting_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                document_number = '', 
                                document_type = '', 
                                account_id = '', 
                                account_number = '', 
                                description = '', 
                                debit_amount = 1.337, 
                                credit_amount = 1.337, 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], 
                        currencies = [
                            pybusinesscentral.model.currency.currency(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                symbol = '', 
                                amount_decimal_places = '', 
                                amount_rounding_precision = 1.337, 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], 
                        payment_methods = [
                            pybusinesscentral.model.payment_method.paymentMethod(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], 
                        dimensions = [
                            pybusinesscentral.model.dimension.dimension(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], 
                        dimension_values = [
                            
                            ], 
                        dimension_lines = [
                            pybusinesscentral.model.dimension_line.dimensionLine(
                                parent_id = '', 
                                id = '', 
                                code = '', 
                                display_name = '', 
                                value_id = '', 
                                value_code = '', 
                                value_display_name = '', )
                            ], 
                        payment_terms = [
                            pybusinesscentral.model.payment_term.paymentTerm(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                due_date_calculation = '', 
                                discount_date_calculation = '', 
                                discount_percent = 1.337, 
                                calculate_discount_on_credit_memos = True, 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], 
                        shipment_methods = [
                            pybusinesscentral.model.shipment_method.shipmentMethod(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], 
                        item_categories = [
                            
                            ], 
                        cash_flow_statement = [
                            pybusinesscentral.model.cash_flow_statement.cashFlowStatement(
                                line_number = 56, 
                                display = '', 
                                net_change = 1.337, 
                                line_type = '', 
                                indentation = 56, 
                                date_filter = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], 
                        countries_regions = [
                            pybusinesscentral.model.country_region.countryRegion(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                address_format = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], 
                        sales_orders = [
                            pybusinesscentral.model.sales_order.salesOrder(
                                id = '', 
                                number = '', 
                                external_document_number = '', 
                                order_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                customer_id = '', 
                                contact_id = '', 
                                customer_number = '', 
                                customer_name = '', 
                                bill_to_name = '', 
                                bill_to_customer_id = '', 
                                bill_to_customer_number = '', 
                                ship_to_name = '', 
                                ship_to_contact = '', 
                                currency_id = '', 
                                currency_code = '', 
                                prices_include_tax = True, 
                                payment_terms_id = '', 
                                shipment_method_id = '', 
                                salesperson = '', 
                                partial_shipping = True, 
                                requested_delivery_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                discount_amount = 1.337, 
                                discount_applied_before_tax = True, 
                                total_amount_excluding_tax = 1.337, 
                                total_tax_amount = 1.337, 
                                total_amount_including_tax = 1.337, 
                                fully_shipped = True, 
                                status = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                phone_number = '', 
                                email = '', 
                                sales_order_lines = [
                                    pybusinesscentral.model.sales_order_line.salesOrderLine(
                                        id = '', 
                                        document_id = '', 
                                        sequence = 56, 
                                        item_id = '', 
                                        account_id = '', 
                                        line_type = '', 
                                        description = '', 
                                        unit_of_measure_id = '', 
                                        quantity = 1.337, 
                                        unit_price = 1.337, 
                                        discount_amount = 1.337, 
                                        discount_percent = 1.337, 
                                        discount_applied_before_tax = True, 
                                        amount_excluding_tax = 1.337, 
                                        tax_code = '', 
                                        tax_percent = 1.337, 
                                        total_tax_amount = 1.337, 
                                        amount_including_tax = 1.337, 
                                        invoice_discount_allocation = 1.337, 
                                        net_amount = 1.337, 
                                        net_tax_amount = 1.337, 
                                        net_amount_including_tax = 1.337, 
                                        shipment_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                                        shipped_quantity = 1.337, 
                                        invoiced_quantity = 1.337, 
                                        invoice_quantity = 1.337, 
                                        ship_quantity = 1.337, )
                                    ], )
                            ], 
                        sales_order_lines = [
                            pybusinesscentral.model.sales_order_line.salesOrderLine(
                                id = '', 
                                document_id = '', 
                                sequence = 56, 
                                item_id = '', 
                                account_id = '', 
                                line_type = '', 
                                description = '', 
                                unit_of_measure_id = '', 
                                quantity = 1.337, 
                                unit_price = 1.337, 
                                discount_amount = 1.337, 
                                discount_percent = 1.337, 
                                discount_applied_before_tax = True, 
                                amount_excluding_tax = 1.337, 
                                tax_code = '', 
                                tax_percent = 1.337, 
                                total_tax_amount = 1.337, 
                                amount_including_tax = 1.337, 
                                invoice_discount_allocation = 1.337, 
                                net_amount = 1.337, 
                                net_tax_amount = 1.337, 
                                net_amount_including_tax = 1.337, 
                                shipment_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                                shipped_quantity = 1.337, 
                                invoiced_quantity = 1.337, 
                                invoice_quantity = 1.337, 
                                ship_quantity = 1.337, )
                            ], 
                        retained_earnings_statement = [
                            pybusinesscentral.model.retained_earnings_statement.retainedEarningsStatement(
                                line_number = 56, 
                                display = '', 
                                net_change = 1.337, 
                                line_type = '', 
                                indentation = 56, 
                                date_filter = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], 
                        units_of_measure = [
                            pybusinesscentral.model.unit_of_measure.unitOfMeasure(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                international_standard_code = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], 
                        aged_accounts_receivable = [
                            pybusinesscentral.model.aged_accounts_receivable.agedAccountsReceivable(
                                customer_id = '', 
                                customer_number = '', 
                                name = '', 
                                currency_code = '', 
                                balance_due = 1.337, 
                                current_amount = 1.337, 
                                period1_amount = 1.337, 
                                period2_amount = 1.337, 
                                period3_amount = 1.337, 
                                aged_as_of_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                period_length_filter = '', )
                            ], 
                        aged_accounts_payable = [
                            pybusinesscentral.model.aged_accounts_payable.agedAccountsPayable(
                                vendor_id = '', 
                                vendor_number = '', 
                                name = '', 
                                currency_code = '', 
                                balance_due = 1.337, 
                                current_amount = 1.337, 
                                period1_amount = 1.337, 
                                period2_amount = 1.337, 
                                period3_amount = 1.337, 
                                aged_as_of_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                period_length_filter = '', )
                            ], 
                        balance_sheet = [
                            pybusinesscentral.model.balance_sheet.balanceSheet(
                                line_number = 56, 
                                display = '', 
                                balance = 1.337, 
                                line_type = '', 
                                indentation = 56, 
                                date_filter = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], 
                        trial_balance = [
                            pybusinesscentral.model.trial_balance.trialBalance(
                                number = '', 
                                account_id = '', 
                                account_type = '', 
                                display = '', 
                                total_debit = '', 
                                total_credit = '', 
                                balance_at_date_debit = '', 
                                balance_at_date_credit = '', 
                                date_filter = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], 
                        income_statement = [
                            pybusinesscentral.model.income_statement.incomeStatement(
                                line_number = 56, 
                                display = '', 
                                net_change = 1.337, 
                                line_type = '', 
                                indentation = 56, 
                                date_filter = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], 
                        tax_areas = [
                            pybusinesscentral.model.tax_area.taxArea(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                tax_type = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], 
                        sales_quotes = [
                            pybusinesscentral.model.sales_quote.salesQuote(
                                id = '', 
                                number = '', 
                                external_document_number = '', 
                                document_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                due_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                customer_id = '', 
                                contact_id = '', 
                                customer_number = '', 
                                customer_name = '', 
                                bill_to_name = '', 
                                bill_to_customer_id = '', 
                                bill_to_customer_number = '', 
                                ship_to_name = '', 
                                ship_to_contact = '', 
                                currency_id = '', 
                                currency_code = '', 
                                payment_terms_id = '', 
                                shipment_method_id = '', 
                                salesperson = '', 
                                discount_amount = 1.337, 
                                total_amount_excluding_tax = 1.337, 
                                total_tax_amount = 1.337, 
                                total_amount_including_tax = 1.337, 
                                status = '', 
                                sent_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                valid_until_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                accepted_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                phone_number = '', 
                                email = '', 
                                sales_quote_lines = [
                                    pybusinesscentral.model.sales_quote_line.salesQuoteLine(
                                        id = '', 
                                        document_id = '', 
                                        sequence = 56, 
                                        item_id = '', 
                                        account_id = '', 
                                        line_type = '', 
                                        description = '', 
                                        unit_of_measure_id = '', 
                                        unit_price = 1.337, 
                                        quantity = 1.337, 
                                        discount_amount = 1.337, 
                                        discount_percent = 1.337, 
                                        discount_applied_before_tax = True, 
                                        amount_excluding_tax = 1.337, 
                                        tax_code = '', 
                                        tax_percent = 1.337, 
                                        total_tax_amount = 1.337, 
                                        amount_including_tax = 1.337, 
                                        net_amount = 1.337, 
                                        net_tax_amount = 1.337, 
                                        net_amount_including_tax = 1.337, )
                                    ], )
                            ], 
                        sales_quote_lines = [
                            pybusinesscentral.model.sales_quote_line.salesQuoteLine(
                                id = '', 
                                document_id = '', 
                                sequence = 56, 
                                item_id = '', 
                                account_id = '', 
                                line_type = '', 
                                description = '', 
                                unit_of_measure_id = '', 
                                unit_price = 1.337, 
                                quantity = 1.337, 
                                discount_amount = 1.337, 
                                discount_percent = 1.337, 
                                discount_applied_before_tax = True, 
                                amount_excluding_tax = 1.337, 
                                tax_code = '', 
                                tax_percent = 1.337, 
                                total_tax_amount = 1.337, 
                                amount_including_tax = 1.337, 
                                net_amount = 1.337, 
                                net_tax_amount = 1.337, 
                                net_amount_including_tax = 1.337, )
                            ], 
                        sales_credit_memos = [
                            pybusinesscentral.model.sales_credit_memo.salesCreditMemo(
                                id = '', 
                                number = '', 
                                external_document_number = '', 
                                credit_memo_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                due_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                customer_id = '', 
                                contact_id = '', 
                                customer_number = '', 
                                customer_name = '', 
                                bill_to_name = '', 
                                bill_to_customer_id = '', 
                                bill_to_customer_number = '', 
                                currency_id = '', 
                                currency_code = '', 
                                payment_terms_id = '', 
                                shipment_method_id = '', 
                                salesperson = '', 
                                prices_include_tax = True, 
                                discount_amount = 1.337, 
                                discount_applied_before_tax = True, 
                                total_amount_excluding_tax = 1.337, 
                                total_tax_amount = 1.337, 
                                total_amount_including_tax = 1.337, 
                                status = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                invoice_id = '', 
                                invoice_number = '', 
                                phone_number = '', 
                                email = '', 
                                sales_credit_memo_lines = [
                                    pybusinesscentral.model.sales_credit_memo_line.salesCreditMemoLine(
                                        id = '', 
                                        document_id = '', 
                                        sequence = 56, 
                                        item_id = '', 
                                        account_id = '', 
                                        line_type = '', 
                                        description = '', 
                                        unit_of_measure_id = '', 
                                        unit_price = 1.337, 
                                        quantity = 1.337, 
                                        discount_amount = 1.337, 
                                        discount_percent = 1.337, 
                                        discount_applied_before_tax = True, 
                                        amount_excluding_tax = 1.337, 
                                        tax_code = '', 
                                        tax_percent = 1.337, 
                                        total_tax_amount = 1.337, 
                                        amount_including_tax = 1.337, 
                                        invoice_discount_allocation = 1.337, 
                                        net_amount = 1.337, 
                                        net_tax_amount = 1.337, 
                                        net_amount_including_tax = 1.337, 
                                        shipment_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), )
                                    ], )
                            ], 
                        sales_credit_memo_lines = [
                            pybusinesscentral.model.sales_credit_memo_line.salesCreditMemoLine(
                                id = '', 
                                document_id = '', 
                                sequence = 56, 
                                item_id = '', 
                                account_id = '', 
                                line_type = '', 
                                description = '', 
                                unit_of_measure_id = '', 
                                unit_price = 1.337, 
                                quantity = 1.337, 
                                discount_amount = 1.337, 
                                discount_percent = 1.337, 
                                discount_applied_before_tax = True, 
                                amount_excluding_tax = 1.337, 
                                tax_code = '', 
                                tax_percent = 1.337, 
                                total_tax_amount = 1.337, 
                                amount_including_tax = 1.337, 
                                invoice_discount_allocation = 1.337, 
                                net_amount = 1.337, 
                                net_tax_amount = 1.337, 
                                net_amount_including_tax = 1.337, 
                                shipment_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), )
                            ], 
                        general_ledger_entry_attachments = [
                            pybusinesscentral.model.general_ledger_entry_attachments.generalLedgerEntryAttachments(
                                general_ledger_entry_number = 56, 
                                id = '', 
                                file_name = '', 
                                byte_size = 56, 
                                content = bytes(b'blah'), 
                                created_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], 
                        purchase_invoices = [
                            pybusinesscentral.model.purchase_invoice.purchaseInvoice(
                                id = '', 
                                number = '', 
                                invoice_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                                due_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                                vendor_invoice_number = '', 
                                vendor_id = '', 
                                vendor_number = '', 
                                vendor_name = '', 
                                pay_to_name = '', 
                                pay_to_contact = '', 
                                pay_to_vendor_id = '', 
                                pay_to_vendor_number = '', 
                                ship_to_name = '', 
                                ship_to_contact = '', 
                                buy_from_address = , 
                                pay_to_address = , 
                                ship_to_address = , 
                                currency_id = '', 
                                currency_code = '', 
                                prices_include_tax = True, 
                                discount_amount = 1.337, 
                                discount_applied_before_tax = True, 
                                total_amount_excluding_tax = 1.337, 
                                total_tax_amount = 1.337, 
                                total_amount_including_tax = 1.337, 
                                status = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                purchase_invoice_lines = [
                                    pybusinesscentral.model.purchase_invoice_line.purchaseInvoiceLine(
                                        id = '', 
                                        document_id = '', 
                                        sequence = 56, 
                                        item_id = '', 
                                        account_id = '', 
                                        line_type = '', 
                                        description = '', 
                                        unit_cost = 1.337, 
                                        quantity = 1.337, 
                                        discount_amount = 1.337, 
                                        discount_percent = 1.337, 
                                        discount_applied_before_tax = True, 
                                        amount_excluding_tax = 1.337, 
                                        tax_code = '', 
                                        tax_percent = 1.337, 
                                        total_tax_amount = 1.337, 
                                        amount_including_tax = 1.337, 
                                        invoice_discount_allocation = 1.337, 
                                        net_amount = 1.337, 
                                        net_tax_amount = 1.337, 
                                        net_amount_including_tax = 1.337, 
                                        expected_receipt_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), )
                                    ], )
                            ], 
                        purchase_invoice_lines = [
                            pybusinesscentral.model.purchase_invoice_line.purchaseInvoiceLine(
                                id = '', 
                                document_id = '', 
                                sequence = 56, 
                                item_id = '', 
                                account_id = '', 
                                line_type = '', 
                                description = '', 
                                unit_cost = 1.337, 
                                quantity = 1.337, 
                                discount_amount = 1.337, 
                                discount_percent = 1.337, 
                                discount_applied_before_tax = True, 
                                amount_excluding_tax = 1.337, 
                                tax_code = '', 
                                tax_percent = 1.337, 
                                total_tax_amount = 1.337, 
                                amount_including_tax = 1.337, 
                                invoice_discount_allocation = 1.337, 
                                net_amount = 1.337, 
                                net_tax_amount = 1.337, 
                                net_amount_including_tax = 1.337, 
                                expected_receipt_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), )
                            ], 
                        projects = [
                            pybusinesscentral.model.project.project(
                                id = '', 
                                number = '', 
                                display_name = '', )
                            ], 
                        bank_accounts = [
                            pybusinesscentral.model.bank_account.bankAccount(
                                id = '', 
                                number = '', 
                                display_name = '', )
                            ], 
                        customer_sales = [
                            pybusinesscentral.model.customer_sale.customerSale(
                                customer_id = '', 
                                customer_number = '', 
                                name = '', 
                                total_sales_amount = 1.337, 
                                date_filter_filter_only = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], 
                        vendor_purchases = [
                            pybusinesscentral.model.vendor_purchase.vendorPurchase(
                                vendor_id = '', 
                                vendor_number = '', 
                                name = '', 
                                total_purchase_amount = 1.337, 
                                date_filter_filter_only = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], )
                    ]
            )
        else:
            return ListCompanies200Response(
        )
        """

    def testListCompanies200Response(self):
        """Test ListCompanies200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    (v2.0) Dynamics 365 Business Central

    (v2.0) Business Central Standard APIs

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from pybusinesscentral.model.account import Account
from pybusinesscentral.model.general_ledger_entry_dimensions_inner import GeneralLedgerEntryDimensionsInner
from typing import Optional, Set
from typing_extensions import Self

class GeneralLedgerEntry(BaseModel):
    """
    GeneralLedgerEntry
    """ # noqa: E501
    id: Optional[StrictInt] = Field(default=None, description="(v1.0) The id property for the Dynamics 365 Business Central generalLedgerEntry entity")
    posting_date: Optional[datetime] = Field(default=None, description="(v1.0) The postingDate property for the Dynamics 365 Business Central generalLedgerEntry entity", alias="postingDate")
    document_number: Optional[Annotated[str, Field(strict=True, max_length=20)]] = Field(default=None, description="(v1.0) The documentNumber property for the Dynamics 365 Business Central generalLedgerEntry entity", alias="documentNumber")
    document_type: Optional[StrictStr] = Field(default=None, description="(v1.0) The documentType property for the Dynamics 365 Business Central generalLedgerEntry entity", alias="documentType")
    account_id: Optional[StrictStr] = Field(default=None, description="(v1.0) The accountId property for the Dynamics 365 Business Central generalLedgerEntry entity", alias="accountId")
    account_number: Optional[Annotated[str, Field(strict=True, max_length=20)]] = Field(default=None, description="(v1.0) The accountNumber property for the Dynamics 365 Business Central generalLedgerEntry entity", alias="accountNumber")
    description: Optional[Annotated[str, Field(strict=True, max_length=100)]] = Field(default=None, description="(v1.0) The description property for the Dynamics 365 Business Central generalLedgerEntry entity")
    debit_amount: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="(v1.0) The debitAmount property for the Dynamics 365 Business Central generalLedgerEntry entity", alias="debitAmount")
    credit_amount: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="(v1.0) The creditAmount property for the Dynamics 365 Business Central generalLedgerEntry entity", alias="creditAmount")
    dimensions: Optional[List[Optional[GeneralLedgerEntryDimensionsInner]]] = None
    last_modified_date_time: Optional[datetime] = Field(default=None, description="(v1.0) The lastModifiedDateTime property for the Dynamics 365 Business Central generalLedgerEntry entity", alias="lastModifiedDateTime")
    account: Optional[Account] = None
    __properties: ClassVar[List[str]] = ["id", "postingDate", "documentNumber", "documentType", "accountId", "accountNumber", "description", "debitAmount", "creditAmount", "dimensions", "lastModifiedDateTime", "account"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of GeneralLedgerEntry from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in dimensions (list)
        _items = []
        if self.dimensions:
            for _item_dimensions in self.dimensions:
                if _item_dimensions:
                    _items.append(_item_dimensions.to_dict())
            _dict['dimensions'] = _items
        # override the default output from pydantic by calling `to_dict()` of account
        if self.account:
            _dict['account'] = self.account.to_dict()
        # set to None if posting_date (nullable) is None
        # and model_fields_set contains the field
        if self.posting_date is None and "posting_date" in self.model_fields_set:
            _dict['postingDate'] = None

        # set to None if document_number (nullable) is None
        # and model_fields_set contains the field
        if self.document_number is None and "document_number" in self.model_fields_set:
            _dict['documentNumber'] = None

        # set to None if document_type (nullable) is None
        # and model_fields_set contains the field
        if self.document_type is None and "document_type" in self.model_fields_set:
            _dict['documentType'] = None

        # set to None if account_id (nullable) is None
        # and model_fields_set contains the field
        if self.account_id is None and "account_id" in self.model_fields_set:
            _dict['accountId'] = None

        # set to None if account_number (nullable) is None
        # and model_fields_set contains the field
        if self.account_number is None and "account_number" in self.model_fields_set:
            _dict['accountNumber'] = None

        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        # set to None if debit_amount (nullable) is None
        # and model_fields_set contains the field
        if self.debit_amount is None and "debit_amount" in self.model_fields_set:
            _dict['debitAmount'] = None

        # set to None if credit_amount (nullable) is None
        # and model_fields_set contains the field
        if self.credit_amount is None and "credit_amount" in self.model_fields_set:
            _dict['creditAmount'] = None

        # set to None if last_modified_date_time (nullable) is None
        # and model_fields_set contains the field
        if self.last_modified_date_time is None and "last_modified_date_time" in self.model_fields_set:
            _dict['lastModifiedDateTime'] = None

        # set to None if account (nullable) is None
        # and model_fields_set contains the field
        if self.account is None and "account" in self.model_fields_set:
            _dict['account'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of GeneralLedgerEntry from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "postingDate": obj.get("postingDate"),
            "documentNumber": obj.get("documentNumber"),
            "documentType": obj.get("documentType"),
            "accountId": obj.get("accountId"),
            "accountNumber": obj.get("accountNumber"),
            "description": obj.get("description"),
            "debitAmount": obj.get("debitAmount"),
            "creditAmount": obj.get("creditAmount"),
            "dimensions": [GeneralLedgerEntryDimensionsInner.from_dict(_item) for _item in obj["dimensions"]] if obj.get("dimensions") is not None else None,
            "lastModifiedDateTime": obj.get("lastModifiedDateTime"),
            "account": Account.from_dict(obj["account"]) if obj.get("account") is not None else None
        })
        return _obj





# coding: utf-8

"""
    (v2.0) Dynamics 365 Business Central

    (v2.0) Business Central Standard APIs

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from pybusinesscentral.model.currency import Currency
from pybusinesscentral.model.customer_financial_detail import CustomerFinancialDetail
from pybusinesscentral.model.default_dimensions import DefaultDimensions
from pybusinesscentral.model.payment_method import PaymentMethod
from pybusinesscentral.model.payment_term import PaymentTerm
from pybusinesscentral.model.picture import Picture
from pybusinesscentral.model.shipment_method import ShipmentMethod
from typing import Optional, Set
from typing_extensions import Self

class Postaladdresstype(BaseModel):
    """
    Postaladdresstype
    """ # noqa: E501
    street: Optional[Annotated[str, Field(strict=True, max_length=152)]] = Field(default=None, description="(v1.0) The street property for the Dynamics 365 Business Central postaladdresstype entity")
    city: Optional[Annotated[str, Field(strict=True, max_length=30)]] = Field(default=None, description="(v1.0) The city property for the Dynamics 365 Business Central postaladdresstype entity")
    state: Optional[Annotated[str, Field(strict=True, max_length=30)]] = Field(default=None, description="(v1.0) The state property for the Dynamics 365 Business Central postaladdresstype entity")
    country_letter_code: Optional[Annotated[str, Field(strict=True, max_length=10)]] = Field(default=None, description="(v1.0) The countryLetterCode property for the Dynamics 365 Business Central postaladdresstype entity", alias="countryLetterCode")
    postal_code: Optional[Annotated[str, Field(strict=True, max_length=20)]] = Field(default=None, description="(v1.0) The postalCode property for the Dynamics 365 Business Central postaladdresstype entity", alias="postalCode")
    customer_financial_details: Optional[List[CustomerFinancialDetail]] = Field(default=None, alias="customerFinancialDetails")
    picture: Optional[List[Picture]] = None
    default_dimensions: Optional[List[DefaultDimensions]] = Field(default=None, alias="defaultDimensions")
    currency: Optional[Currency] = None
    payment_term: Optional[PaymentTerm] = Field(default=None, alias="paymentTerm")
    shipment_method: Optional[ShipmentMethod] = Field(default=None, alias="shipmentMethod")
    payment_method: Optional[PaymentMethod] = Field(default=None, alias="paymentMethod")
    __properties: ClassVar[List[str]] = ["street", "city", "state", "countryLetterCode", "postalCode", "customerFinancialDetails", "picture", "defaultDimensions", "currency", "paymentTerm", "shipmentMethod", "paymentMethod"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Postaladdresstype from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in customer_financial_details (list)
        _items = []
        if self.customer_financial_details:
            for _item_customer_financial_details in self.customer_financial_details:
                if _item_customer_financial_details:
                    _items.append(_item_customer_financial_details.to_dict())
            _dict['customerFinancialDetails'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in picture (list)
        _items = []
        if self.picture:
            for _item_picture in self.picture:
                if _item_picture:
                    _items.append(_item_picture.to_dict())
            _dict['picture'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in default_dimensions (list)
        _items = []
        if self.default_dimensions:
            for _item_default_dimensions in self.default_dimensions:
                if _item_default_dimensions:
                    _items.append(_item_default_dimensions.to_dict())
            _dict['defaultDimensions'] = _items
        # override the default output from pydantic by calling `to_dict()` of currency
        if self.currency:
            _dict['currency'] = self.currency.to_dict()
        # override the default output from pydantic by calling `to_dict()` of payment_term
        if self.payment_term:
            _dict['paymentTerm'] = self.payment_term.to_dict()
        # override the default output from pydantic by calling `to_dict()` of shipment_method
        if self.shipment_method:
            _dict['shipmentMethod'] = self.shipment_method.to_dict()
        # override the default output from pydantic by calling `to_dict()` of payment_method
        if self.payment_method:
            _dict['paymentMethod'] = self.payment_method.to_dict()
        # set to None if street (nullable) is None
        # and model_fields_set contains the field
        if self.street is None and "street" in self.model_fields_set:
            _dict['street'] = None

        # set to None if city (nullable) is None
        # and model_fields_set contains the field
        if self.city is None and "city" in self.model_fields_set:
            _dict['city'] = None

        # set to None if state (nullable) is None
        # and model_fields_set contains the field
        if self.state is None and "state" in self.model_fields_set:
            _dict['state'] = None

        # set to None if country_letter_code (nullable) is None
        # and model_fields_set contains the field
        if self.country_letter_code is None and "country_letter_code" in self.model_fields_set:
            _dict['countryLetterCode'] = None

        # set to None if postal_code (nullable) is None
        # and model_fields_set contains the field
        if self.postal_code is None and "postal_code" in self.model_fields_set:
            _dict['postalCode'] = None

        # set to None if customer_financial_details (nullable) is None
        # and model_fields_set contains the field
        if self.customer_financial_details is None and "customer_financial_details" in self.model_fields_set:
            _dict['customerFinancialDetails'] = None

        # set to None if picture (nullable) is None
        # and model_fields_set contains the field
        if self.picture is None and "picture" in self.model_fields_set:
            _dict['picture'] = None

        # set to None if default_dimensions (nullable) is None
        # and model_fields_set contains the field
        if self.default_dimensions is None and "default_dimensions" in self.model_fields_set:
            _dict['defaultDimensions'] = None

        # set to None if currency (nullable) is None
        # and model_fields_set contains the field
        if self.currency is None and "currency" in self.model_fields_set:
            _dict['currency'] = None

        # set to None if payment_term (nullable) is None
        # and model_fields_set contains the field
        if self.payment_term is None and "payment_term" in self.model_fields_set:
            _dict['paymentTerm'] = None

        # set to None if shipment_method (nullable) is None
        # and model_fields_set contains the field
        if self.shipment_method is None and "shipment_method" in self.model_fields_set:
            _dict['shipmentMethod'] = None

        # set to None if payment_method (nullable) is None
        # and model_fields_set contains the field
        if self.payment_method is None and "payment_method" in self.model_fields_set:
            _dict['paymentMethod'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Postaladdresstype from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "street": obj.get("street"),
            "city": obj.get("city"),
            "state": obj.get("state"),
            "countryLetterCode": obj.get("countryLetterCode"),
            "postalCode": obj.get("postalCode"),
            "customerFinancialDetails": [CustomerFinancialDetail.from_dict(_item) for _item in obj["customerFinancialDetails"]] if obj.get("customerFinancialDetails") is not None else None,
            "picture": [Picture.from_dict(_item) for _item in obj["picture"]] if obj.get("picture") is not None else None,
            "defaultDimensions": [DefaultDimensions.from_dict(_item) for _item in obj["defaultDimensions"]] if obj.get("defaultDimensions") is not None else None,
            "currency": Currency.from_dict(obj["currency"]) if obj.get("currency") is not None else None,
            "paymentTerm": PaymentTerm.from_dict(obj["paymentTerm"]) if obj.get("paymentTerm") is not None else None,
            "shipmentMethod": ShipmentMethod.from_dict(obj["shipmentMethod"]) if obj.get("shipmentMethod") is not None else None,
            "paymentMethod": PaymentMethod.from_dict(obj["paymentMethod"]) if obj.get("paymentMethod") is not None else None
        })
        return _obj






# flake8: noqa

# Import all APIs into this package.
# If you have many APIs here with many many models used in each API this may
# raise a `RecursionError`.
# In order to avoid this, import only the API that you directly need like:
#
#   from .api.account_api import AccountApi
#
# or import this package, but before doing it, use:
#
#   import sys
#   sys.setrecursionlimit(n)

# Import APIs into API package:
from pybusinesscentral.api.account_api import AccountApi
from pybusinesscentral.api.company_api import CompanyApi
from pybusinesscentral.api.customer_api import CustomerApi
from pybusinesscentral.api.dimension_api import DimensionApi
from pybusinesscentral.api.dimension_set_line_api import DimensionSetLineApi
from pybusinesscentral.api.payment_term_api import PaymentTermApi
from pybusinesscentral.api.purchase_invoice_api import PurchaseInvoiceApi
from pybusinesscentral.api.sales_invoice_api import SalesInvoiceApi
from pybusinesscentral.api.sales_invoice_line_api import SalesInvoiceLineApi
from pybusinesscentral.api.sales_credit_memo_api import SalesCreditMemoApi
from pybusinesscentral.api.sales_credit_memo_line_api import SalesCreditMemoLineApi
from pybusinesscentral.api.vendor_api import VendorApi



# coding: utf-8

"""
    (v2.0) Dynamics 365 Business Central

    (v2.0) Business Central Standard APIs

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pybusinesscentral.model.bank_account import BankAccount

class TestBankAccount(unittest.TestCase):
    """BankAccount unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BankAccount:
        """Test BankAccount
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `BankAccount`
        """
        model = BankAccount()
        if include_optional:
            return BankAccount(
                id = '',
                number = '',
                display_name = ''
            )
        else:
            return BankAccount(
        )
        """

    def testBankAccount(self):
        """Test BankAccount"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    (v2.0) Dynamics 365 Business Central

    (v2.0) Business Central Standard APIs

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pybusinesscentral.model.list_customers200_response import ListCustomers200Response

class TestListCustomers200Response(unittest.TestCase):
    """ListCustomers200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ListCustomers200Response:
        """Test ListCustomers200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ListCustomers200Response`
        """
        model = ListCustomers200Response()
        if include_optional:
            return ListCustomers200Response(
                value = [
                    pybusinesscentral.model.customer.customer(
                        id = '', 
                        number = '', 
                        display_name = '', 
                        type = '', 
                        address_line1 = '', 
                        address_line2 = '', 
                        city = '', 
                        state = '', 
                        country = '', 
                        postal_code = '', 
                        phone_number = '', 
                        email = '', 
                        website = '', 
                        tax_liable = True, 
                        tax_area_id = '', 
                        tax_area_display_name = '', 
                        tax_registration_number = '', 
                        currency_id = '', 
                        currency_code = '', 
                        payment_terms_id = '', 
                        shipment_method_id = '', 
                        payment_method_id = '', 
                        blocked = '', 
                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        customer_financial_details = [
                            pybusinesscentral.model.customer_financial_detail.customerFinancialDetail(
                                id = '', 
                                number = '', 
                                balance = 1.337, 
                                total_sales_excluding_tax = 1.337, 
                                overdue_amount = 1.337, )
                            ], 
                        picture = [
                            pybusinesscentral.model.picture.picture(
                                id = '', 
                                width = 56, 
                                height = 56, 
                                content_type = '', 
                                content@odata/media_edit_link = '', 
                                content@odata/media_read_link = '', )
                            ], 
                        default_dimensions = [
                            pybusinesscentral.model.default_dimensions.defaultDimensions(
                                parent_id = '', 
                                dimension_id = '', 
                                dimension_code = '', 
                                dimension_value_id = '', 
                                dimension_value_code = '', 
                                posting_validation = '', 
                                account = pybusinesscentral.model.account.account(
                                    id = '', 
                                    number = '', 
                                    display_name = '', 
                                    category = '', 
                                    sub_category = '', 
                                    blocked = True, 
                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                                dimension = pybusinesscentral.model.dimension.dimension(
                                    id = '', 
                                    code = '', 
                                    display_name = '', 
                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    dimension_values = [
                                        pybusinesscentral.model.dimension_value.dimensionValue(
                                            id = '', 
                                            code = '', 
                                            display_name = '', 
                                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                        ], ), 
                                dimension_value = pybusinesscentral.model.dimension_value.dimensionValue(
                                    id = '', 
                                    code = '', 
                                    display_name = '', 
                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                            ], 
                        currency = pybusinesscentral.model.currency.currency(
                            id = '', 
                            code = '', 
                            display_name = '', 
                            symbol = '', 
                            amount_decimal_places = '', 
                            amount_rounding_precision = 1.337, 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        payment_term = pybusinesscentral.model.payment_term.paymentTerm(
                            id = '', 
                            code = '', 
                            display_name = '', 
                            due_date_calculation = '', 
                            discount_date_calculation = '', 
                            discount_percent = 1.337, 
                            calculate_discount_on_credit_memos = True, 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        shipment_method = pybusinesscentral.model.shipment_method.shipmentMethod(
                            id = '', 
                            code = '', 
                            display_name = '', 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        payment_method = pybusinesscentral.model.payment_method.paymentMethod(
                            id = '', 
                            code = '', 
                            display_name = '', 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                    ]
            )
        else:
            return ListCustomers200Response(
        )
        """

    def testListCustomers200Response(self):
        """Test ListCustomers200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
